<?php
/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( !isset($content_width) )
	$content_width = 768;

/**
 * Theme set up
 */
if ( !function_exists('mnmd_bone_theme_setup') ){

	function mnmd_bone_theme_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 */
		load_theme_textdomain( 'bone', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );
	
		// Register navigation menu
		register_nav_menus(
			array(
				'main-menu' => esc_html__('Primary Menu', 'bone'),
				'footer-menu' => esc_html__('Footer Menu', 'bone'),
			)
		);
		
		/*
		 * Enable support for Post Formats.
		 */
		add_theme_support( 'post-formats', array( 'gallery', 'image', 'video', 'audio' ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
		) );
		
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'mnmd_bone_cover', 2560, 1440, false );
		add_image_size( 'mnmd_bone_xl', 1288, 725, false );
		add_image_size( 'mnmd_bone_lg', 880, 495, false );
		add_image_size( 'mnmd_bone_sm', 506, 380, true );
		add_image_size( 'mnmd_bone_xs', 120, 120, true );

		/*
		 * Add support for Gutenberg's wide and full alignment.
		 */
		add_theme_support( 'align-wide' );

		/*
		 * Add Gutenberg's default block styles.
		 */
		add_theme_support( 'wp-block-styles' );

		/*
		 * Add Gutenberg's responsive embed styles.
		 */
		add_theme_support( 'responsive-embeds' );

		// Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => __( 'Small', 'bone' ),
					'shortName' => __( 'S', 'bone' ),
					'size'      => 12.64,
					'slug'      => 'small',
				),
				array(
					'name'      => __( 'Normal', 'bone' ),
					'shortName' => __( 'M', 'bone' ),
					'size'      => 16,
					'slug'      => 'normal',
				),
				array(
					'name'      => __( 'Large', 'bone' ),
					'shortName' => __( 'L', 'bone' ),
					'size'      => 20.256,
					'slug'      => 'large',
				),
				array(
					'name'      => __( 'Huge', 'bone' ),
					'shortName' => __( 'XL', 'bone' ),
					'size'      => 25.632,
					'slug'      => 'huge',
				),
			)
		);

		/*
		 * Remove support for Widget Block.
		 */
		remove_theme_support( 'widgets-block-editor' );
	}

}
add_action( 'after_setup_theme', 'mnmd_bone_theme_setup' );

/**
 * Register and enqueue styles/scripts
 */
if ( !function_exists('mnmd_bone_scripts') ){
	function mnmd_bone_scripts(){

		// Enqueue styles

		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/vendors/bootstrap/bootstrap.min.css', array(), '3.3.4');

		wp_enqueue_style('fotorama', get_template_directory_uri() . '/vendors/fotorama/fotorama.css', array(), '4.6.4');

		wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/vendors/owl-carousel/owl.carousel.min.css', array(), '2.2.1');

		wp_enqueue_style('zoom-js', get_template_directory_uri() . '/vendors/zoom/zoom.css', array(), '0.0.2');

		$current_theme = wp_get_theme();
		$theme_version = $current_theme->get( 'Version' );
		wp_enqueue_style('md-bone-style', get_template_directory_uri() . '/style.css', array(), $theme_version);

		// Enqueue scripts

		wp_enqueue_script('bootstrap', get_template_directory_uri() . '/vendors/bootstrap/bootstrap.min.js', array('jquery'), '3.3.7', true);

		wp_enqueue_script('fotorama', get_template_directory_uri() . '/vendors/fotorama/fotorama.js', array(), '4.6.4', true);

		wp_enqueue_script( 'masonry', '', array('jquery'), '', true );

		wp_enqueue_script('theia-sticky-sidebar', get_template_directory_uri() . '/vendors/theia-sticky-sidebar/theia-sticky-sidebar.min.js', array('jquery'), '1.7.0', true);

		wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/vendors/owl-carousel/owl.carousel.min.js', array('jquery'), '2.2.1', true);

		wp_enqueue_script('zoom-js', get_template_directory_uri() . '/vendors/zoom/zoom.min.js', array(), '0.0.2', true);

		wp_enqueue_script('md-bone-scripts', get_template_directory_uri() . '/assets/js/md-scripts.js', array('jquery'), false, true);

		//add the comments reply to script on single pages
		if (is_single()) {
			wp_enqueue_script('comment-reply');
		}
	}
}
add_action( 'wp_enqueue_scripts','mnmd_bone_scripts' );

/**
 * Enqueue the stylesheet for Customizer.
 */
if ( ! function_exists( 'mnmd_bone_customizer_styles' ) ) {
	function mnmd_bone_customizer_styles() {
		wp_register_style( 'mnmd-bone-customizer-css', get_template_directory_uri() . '/assets/css/customizer.css', NULL, NULL, 'all' );
		wp_enqueue_style( 'mnmd-bone-customizer-css' );
	}
	add_action( 'customize_controls_print_styles', 'mnmd_bone_customizer_styles' );
}

/**
 * Add inline CSS for backend.
 */
if ( ! function_exists( 'mnmd_bone_admin_css' ) ) {
	function mnmd_bone_admin_css() {
		if ( ! class_exists( 'Redux' ) )
			return; // Redux Framework isn't activated!

		$body_font_selectors = '.editor-styles-wrapper.editor-styles-wrapper';

		$heading_font_selectors = '.editor-post-title__block .editor-post-title__input, .editor-styles-wrapper.editor-styles-wrapper h1, .editor-styles-wrapper.editor-styles-wrapper h2, .editor-styles-wrapper.editor-styles-wrapper h3, .editor-styles-wrapper.editor-styles-wrapper h4, .editor-styles-wrapper.editor-styles-wrapper h5, .editor-styles-wrapper.editor-styles-wrapper h6';

		$meta_font_selectors = 'label,input[type=submit],.metaText,.metaFont,.metaBtn,.postMeta,.postCategory,.blockHeading,.comment-reply-title,.wp-caption,.gallery-caption,.widget-title,.btn,.navigation,.logged-in-as,.widget_calendar table,.tagcloud a,.widget_nav_menu .menu,.widget_categories li,.widget_meta li > a,.widget_pages li,.widget_archive a,.comment-reply-title small,.wpp-meta,.wpp-list-with-thumbnails > li > a:first-child:after,.wpp-list:not(.wpp-list-with-thumbnails) > li:before';

		$heading_font = mnmd_bone_get_option( 'title-typography', array() );
		$body_font = mnmd_bone_get_option( 'body-typography', array() );
		$meta_font = mnmd_bone_get_option( 'meta-typography', array() );

		$output_css = '';
		$output_css .= $body_font_selectors . '{font-family:' . $body_font[ 'font-family' ] . ';}';
		$output_css .= $heading_font_selectors . '{font-family:' . $heading_font[ 'font-family' ] . ';}';
		$output_css .= $meta_font_selectors . '{font-family:' . $meta_font[ 'font-family' ] . ';}';

		// Other custom CSS styles
		$primary_color = mnmd_bone_get_option('primary-color', '#4baea0');
		$output_css .= $primary_color_bg_selectors . '{background-color:' . $primary_color . ';}';

		echo '<style id="md-bone-admin-inline-css" type="text/css">';
		echo esc_html( $output_css );
		echo '</style>';
	}
}
// add_action( 'admin_print_scripts', 'mnmd_bone_admin_css' );

/**
 * Add inline CSS for backend editor.
 */
if ( ! function_exists( 'mnmd_bone_editor_style' ) ) {
	function mnmd_bone_editor_style( $hook ) {

		if ( $hook === 'post-new.php' || $hook === 'post.php' ) {
			$inline_css = '';

			// Get options.
			$primary_color = mnmd_bone_get_option( 'primary_color', '#000' );
    		$body_typography = mnmd_bone_get_option( 'body_typography', array() );
	    	$heading_typography = mnmd_bone_get_option( 'heading_typography', array() );
	    	$meta_typography = mnmd_bone_get_option( 'meta_typography', array() );
	    	$post_body_typography = mnmd_bone_get_option( 'post_body_typography', array() );
	    	$post_body_typography_mobile = mnmd_bone_get_option( 'post_body_typography_mobile', array() );

	    	// Set defaults.
	    	$body_typography = wp_parse_args( $body_typography, array(
	    		'font-family' => 'Inter',
	    		'font-weight' => 'regular',
	    	));

	    	$heading_typography = wp_parse_args( $heading_typography, array(
	    		'font-family' => 'Inter',
	    		'font-weight' => 'regular',
	    	));

	    	$meta_typography = wp_parse_args( $meta_typography, array(
	    		'font-family' => 'Inter',
	    		'font-weight' => 'regular',
	    	));

	    	$post_body_typography = wp_parse_args( $post_body_typography, array(
	    		'font-family' => 'Inter',
	    		'font-weight' => 'regular',
	    		'font-size' => '18px',
	    		'line-height' => '1.7',
	    	));

	    	$post_body_typography_mobile = wp_parse_args( $post_body_typography_mobile, array(
	    		'font-family' => 'Inter',
	    		'font-weight' => 'regular',
	    		'font-size' => '16px',
	    		'line-height' => '1.6',
	    	));

	    	// Setting up variables.
	    	$post_body_line_height = $post_body_typography['line-height'];
    		$post_body_line_height_mobile = $post_body_typography_mobile['line-height'];
    		$post_body_font_size = $post_body_typography['font-size'];
			$post_body_font_size_mobile = $post_body_typography_mobile['font-size'];
			$post_body_line_height = $post_body_typography['line-height'];
	    	$post_body_line_height_sm = $post_body_typography_mobile['line-height'];
	    	$dropcap_rows = 3;
			$dropcap_letter_ratio = 0.75;
			$dropcap_font_size = ( ( $post_body_line_height * $dropcap_rows ) - ( $post_body_line_height - 1 ) ) / $dropcap_letter_ratio;
			$dropcap_font_size_mobile = ( ( $post_body_line_height_mobile * $dropcap_rows ) - ( $post_body_line_height_mobile - 1 ) ) / $dropcap_letter_ratio;

    		$primary_color_bg_selectors = '
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-primary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-primary,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-primary:visited,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:hover,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:focus,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .st-btn-secondary:active,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:hover,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:focus,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform a.st-btn-secondary:active,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform .btn.st-btn-outline:before';

	    	$body_typography_selectors = '
				.editor-styles-wrapper.editor-styles-wrapper,
				.editor-styles-wrapper.editor-styles-wrapper .widget-calendar,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-calendar,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-tag-cloud a';

			$post_body_typography_selectors = '
				.editor-styles-wrapper.editor-styles-wrapper';

		    $heading_typography_selectors = '
		    	.editor-post-title__block.editor-post-title__block .editor-post-title__input,
		    	.editor-styles-wrapper.editor-styles-wrapper h1,
		    	.editor-styles-wrapper.editor-styles-wrapper h2,
		    	.editor-styles-wrapper.editor-styles-wrapper h3,
		    	.editor-styles-wrapper.editor-styles-wrapper h4,
		    	.editor-styles-wrapper.editor-styles-wrapper h5,
		    	.editor-styles-wrapper.editor-styles-wrapper h6,
		    	.editor-styles-wrapper.editor-styles-wrapper .widget_calendar caption,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-calendar table caption,
		    	.editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-comments__comment-meta,
		    	.editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-posts li a,
		    	.editor-styles-wrapper.editor-styles-wrapper .wp-block-rss__item-title';

		    $meta_typography_selectors = '
			    .editor-styles-wrapper.editor-styles-wrapper label,
			    .editor-styles-wrapper.editor-styles-wrapper button,
			    .editor-styles-wrapper.editor-styles-wrapper input[type=submit],
			    .editor-styles-wrapper.editor-styles-wrapper figcaption,
			    .editor-styles-wrapper.editor-styles-wrapper .metaText,
			    .editor-styles-wrapper.editor-styles-wrapper .metaFont,
			    .editor-styles-wrapper.editor-styles-wrapper .metaBtn,
			    .editor-styles-wrapper.editor-styles-wrapper .postMeta,
			    .editor-styles-wrapper.editor-styles-wrapper .postCategory,
			    .editor-styles-wrapper.editor-styles-wrapper .blockHeading,
			    .editor-styles-wrapper.editor-styles-wrapper .comment-reply-title,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-caption,
			    .editor-styles-wrapper.editor-styles-wrapper .gallery-caption,
			    .editor-styles-wrapper.editor-styles-wrapper .widget-title,
			    .editor-styles-wrapper.editor-styles-wrapper .btn,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-archives,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-archives select,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-button__link,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-categories,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-categories select,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-file__button,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-quote__citation,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-quote cite,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-quote footer,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote p,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote__citation,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote cite,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-pullquote footer,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-comments__comment-date,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_recent_entries .post-date,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-posts__post-author,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-latest-posts__post-date,
			    .editor-styles-wrapper.editor-styles-wrapper .wp-block-rss__item-author,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-rss__item-publish-date,
    			.editor-styles-wrapper.editor-styles-wrapper .wp-block-search .wp-block-search__button.wp-block-search__button.wp-block-search__button,
			    .editor-styles-wrapper.editor-styles-wrapper .navigation,
			    .editor-styles-wrapper.editor-styles-wrapper .logged-in-as,
			    .editor-styles-wrapper.editor-styles-wrapper .tagcloud a,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_nav_menu .menu,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_categories li,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_meta li > a,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_pages li,
			    .editor-styles-wrapper.editor-styles-wrapper .widget_archive a,
			    .editor-styles-wrapper.editor-styles-wrapper .comment-reply-title small,
			    .editor-styles-wrapper.editor-styles-wrapper .wpp-meta,
			    .editor-styles-wrapper.editor-styles-wrapper .wpp-list-with-thumbnails > li > a:first-child:after,
			    .editor-styles-wrapper.editor-styles-wrapper .wpp-list:not(.wpp-list-with-thumbnails) > li:before';

			$inline_css .= $primary_color_bg_selectors.'{ background-color:' . $primary_color . '; }';

			if ( array_key_exists( 'font-family', $body_typography) && $body_typography['font-family'] ) {
				$inline_css .= $body_typography_selectors . '{font-family:' . $body_typography['font-family'] . ';}';
			}

			if ( array_key_exists( 'font-weight', $body_typography) && $body_typography['font-weight'] ) {
				$inline_css .= $body_typography_selectors . '{font-weight:' . $body_typography['font-weight'] . ';}';
			}

			if ( array_key_exists( 'font-family', $post_body_typography) && $post_body_typography['font-family'] ) {
				$inline_css .= $body_typography_selectors . '{font-family:' . $post_body_typography['font-family'] . ';}';
			}

			if ( array_key_exists( 'font-weight', $post_body_typography) && $post_body_typography['font-weight'] ) {
				$inline_css .= $body_typography_selectors . '{font-weight:' . $post_body_typography['font-weight'] . ';}';
			}

			if ( array_key_exists( 'font-family', $heading_typography) && $heading_typography['font-family'] ) {
				$inline_css .= $body_typography_selectors . '{font-family:' . $heading_typography['font-family'] . ';}';
			}

			if ( array_key_exists( 'font-weight', $heading_typography) && $heading_typography['font-weight'] ) {
				$inline_css .= $body_typography_selectors . '{font-weight:' . $heading_typography['font-weight'] . ';}';
			}

			if ( array_key_exists( 'font-family', $meta_typography) && $meta_typography['font-family'] ) {
				$inline_css .= $body_typography_selectors . '{font-family:' . $meta_typography['font-family'] . ';}';
			}

			if ( array_key_exists( 'font-weight', $meta_typography) && $meta_typography['font-weight'] ) {
				$inline_css .= $body_typography_selectors . '{font-weight:' . $meta_typography['font-weight'] . ';}';
			}

	    	$inline_css .= '
	    		.editor-styles-wrapper.editor-styles-wrapper > *,
				.editor-styles-wrapper.editor-styles-wrapper p,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
					font-size: ' . $post_body_font_size_mobile . ';
				}';

	    	$inline_css .= '
	    		@media (min-width: 576px) {
		    		.editor-styles-wrapper.editor-styles-wrapper > *,
					.editor-styles-wrapper.editor-styles-wrapper p,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
						font-size: ' . $post_body_font_size . ';
					}
				}';

			$inline_css .= '
	    		.editor-styles-wrapper.editor-styles-wrapper > *,
				.editor-styles-wrapper.editor-styles-wrapper p,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
				.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
					line-height: ' . $post_body_line_height_mobile . ';
				}';

	    	$inline_css .= '
	    		@media (min-width: 576px) {
		    		.editor-styles-wrapper.editor-styles-wrapper > *,
					.editor-styles-wrapper.editor-styles-wrapper p,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce li,
					.editor-styles-wrapper.editor-styles-wrapper .wp-block-freeform.block-library-rich-text__tinymce p {
						line-height: ' . $post_body_line_height . ';
					}
				}';

			$inline_css .= '
    			.block-editor-writing-flow .block-editor-block-list__block[data-type="core/paragraph"].has-drop-cap:not(:focus):first-letter {
    				font-size: ' . $dropcap_font_size_mobile . 'em;
    				line-height: ' . $dropcap_letter_ratio . ';
    				margin-top: ' . ( ( 1 - $dropcap_letter_ratio ) * ( 1 - ( 1 / $dropcap_font_size_mobile ) ) / 2 ) . 'em;
    			}';

    		$inline_css .= '
    			@media (min-width: 576px) {
    				.block-editor-writing-flow .block-editor-block-list__block[data-type="core/paragraph"].has-drop-cap:not(:focus):first-letter {
    					font-size: ' . $dropcap_font_size . 'em;
    					line-height: ' . $dropcap_letter_ratio . ';
    					margin-top: ' . ( ( 1 - $dropcap_letter_ratio ) * ( 1 - ( 1 / $dropcap_font_size ) ) / 2 ) . 'em;
    				}
    			}';

			echo '<style id="mnmd-bone-editor-css" type="text/css">';
			echo strip_tags( $inline_css );
			echo '</style>';
		}
	}
	add_action( 'admin_enqueue_scripts', 'mnmd_bone_editor_style' );
}

/**
 * Register theme's frontend variable
 */
if ( !function_exists('mnmd_bone_frontend_variable') ){
	function mnmd_bone_frontend_variable(){

		// Ajax load posts vars
		global $wp_query;
		// What page are we on? And what is the pages limit?
		$posts_per_page = (int)get_option( 'posts_per_page' );
		$max = $wp_query->max_num_pages;
		$query_vars = $wp_query->query;

		if (current_user_can('read_private_posts')) {
			$post_status = array("publish", "private");
		} else {
			$post_status = "publish";
		}

		if (empty($query_vars)) {
			$query_vars = array(
				"post_status" => $post_status,
				"posts_per_page" => $posts_per_page,
			);
		}

		$paged = ( get_query_var('paged') > 1 ) ? get_query_var('paged') : 1;
		$ajaxloadpost = array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'failText' => esc_html__("Can't load posts", 'bone'),
			'loadingText' => esc_html__('Loading posts', 'bone'),
			'noMoreText' => esc_html__('No posts left', 'bone'),
			'query_vars' => $query_vars,
			'startPage' => $paged,
			'maxPages' => $max,
		);

		if (is_admin_bar_showing()) {
			$fixed_offset = 72;
			$has_adminbar = true;
		} else {
			$fixed_offset = 40;
			$has_adminbar = false;
		}

		// Sticky header
		$sticky_header_switch = mnmd_bone_get_option('sticky_header', 'yes');
		$sticky_header = array('toggle' => $sticky_header_switch, 'hasAdminBar' => $has_adminbar);

		// Sticky sidebar
		$sticky_sidebar_switch = mnmd_bone_get_option('sticky_sidebar', 'yes');
		$sb_offset_top = ($sticky_header_switch === 'yes'? (104 + $fixed_offset): $fixed_offset);
		$sticky_sidebar = array('toggle' => $sticky_sidebar_switch, 'offsetTop' => $sb_offset_top );

		// Parallax effect on single billboard
		$parallax_toggle = mnmd_bone_get_option('parallax-switch', true);

		// Get curent page uri
		$current_rel_uri = add_query_arg( NULL, NULL );

		// High resolution compatible
		$high_resolution = mnmd_bone_get_option('high-resolution-switch', '0');

		// Featured slider options
		$slider_autoplay = (boolean)mnmd_bone_get_option('featured_posts_autoplay_slider_toggle', '0');
		$slider_autoplay_timeout = (int)mnmd_bone_get_option('featured_posts_autoplay_slider_timeout', '5000');
		$slider_opts = array(
			'autoplay' => $slider_autoplay,
			'timeout'  => $slider_autoplay_timeout,
		);

		$mnmd_bone_var = array(
			'ajaxloadpost' => $ajaxloadpost,
			'stickySidebar' => $sticky_sidebar,
			'stickyHeader' => $sticky_header,
			'currentRelURI' => $current_rel_uri,
			'parallaxToggle' => $parallax_toggle,
			'highResolution' => $high_resolution,
			'sliderOpts' => $slider_opts,
		);
		wp_localize_script( 'md-bone-scripts', 'mdBoneVar', $mnmd_bone_var );
	}
}
add_action( 'wp_enqueue_scripts','mnmd_bone_frontend_variable' );

/**
 * Include the TGM plugin activation configuration file.
 */
if ( !function_exists( 'mnmd_bone_tgmpa_plugin_implement' ) ) {
	function mnmd_bone_tgmpa_plugin_implement() {
		if ( file_exists( get_template_directory() . '/inc/tgmpa-configs.php' ) ) {
		    require_once get_template_directory() . '/inc/tgmpa-configs.php';
		}
	}
	add_action( 'after_setup_theme', 'mnmd_bone_tgmpa_plugin_implement' );
}

/**
 * Implement Theme Options panel.
 */
if ( !function_exists( 'mnmd_bone_customizer' ) ) {
	function mnmd_bone_customizer() {
		if ( class_exists( 'Kirki' ) && file_exists( get_template_directory() . '/inc/theme-customizer.php' ) ) {
			require_once get_template_directory() . '/inc/theme-customizer.php';
		}
	}
	add_action( 'after_setup_theme', 'mnmd_bone_customizer' );
}

/**
 * Implement ACF fields.
 */
get_template_part( 'inc/acf-configs' );

/**
 * Include theme function files
 */

// Metabox config
get_template_part( 'inc/minimaldog-metabox-config' );

// Theme utilities
get_template_part( 'inc/minimaldog-utilities' );

/**
 * Register sidebars
 */
if ( !function_exists('mnmd_bone_widgets_init') ){
	function mnmd_bone_widgets_init(){
		register_sidebar(array(
			'id' => 'home-sidebar',
			'name' => esc_html__('Home Sidebar', 'bone'),
			'description'   => esc_html__('Appears on Front Page', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'single-sidebar',
			'name' => esc_html__('Single Sidebar', 'bone'),
			'description'   => esc_html__('Appears on single posts', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'default-sidebar',
			'name' => esc_html__('Default Sidebar', 'bone'),
			'description'   => esc_html__('Appears on other pages', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'header-sidebar',
			'name' => esc_html__('Header Widget Area', 'bone'),
			'description'   => esc_html__('Appears in site header', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'adsidebar-1',
			'name' => esc_html__('Ad Area 1', 'bone'),
			'description'   => esc_html__('Appears above home content', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'adsidebar-2',
			'name' => esc_html__('Ad Area 2', 'bone'),
			'description'   => esc_html__('Appears at bottom of page', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'adsidebar-3',
			'name' => esc_html__('Ad Area 3', 'bone'),
			'description'   => esc_html__('Appears under post content', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'footer-sidebar-1',
			'name' => esc_html__('Footer Sidebar 1', 'bone'),
			'description'   => esc_html__('Appears under featured section of home page', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'footer-sidebar-2',
			'name' => esc_html__('Footer Sidebar 2', 'bone'),
			'description'   => esc_html__('Appears at top of posts and pages', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
		register_sidebar(array(
			'id' => 'footer-sidebar-3',
			'name' => esc_html__('Footer Sidebar 3', 'bone'),
			'description'   => esc_html__('Appears at the bottom of posts and pages', 'bone'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h4 class="widget-title">',
			'after_title' => '</h4>',
		));
	}
}
add_action( 'widgets_init', 'mnmd_bone_widgets_init' );

/**
 * Enqueue supplemental block editor styles.
 */
function mnmd_bone_block_editor_styles() {

	$css_dependencies = array();

	// Enqueue the editor styles.
	wp_enqueue_style( 'md-bone-block-editor-styles', get_template_directory_uri() . '/assets/css/editor-style-block.css', $css_dependencies, wp_get_theme()->get( 'Version' ), 'all' );
}

add_action( 'enqueue_block_editor_assets', 'mnmd_bone_block_editor_styles', 1, 1 );

/**
 * Enqueue classic editor styles.
 */
function mnmd_bone_classic_editor_styles() {
	add_theme_support( 'editor-styles' );
	add_editor_style( get_template_directory_uri() . '/assets/css/editor-style-classic.css' );
}

// add_action( 'init', 'mnmd_bone_classic_editor_styles' );

/**
 * Get theme option value.
 */
if ( ! function_exists( 'mnmd_bone_get_option' ) ) {
	function mnmd_bone_get_option( $opt, $default = NULL ) {
		$prefix = 'mnmd_bone_';
		return get_theme_mod( $prefix . $opt, $default );
	}
}

/**
 * Get single post/page option value.
 */
if ( ! function_exists( 'mnmd_bone_get_single_option' ) ) {
	function mnmd_bone_get_single_option( $opt, $default = NULL ) {
		$option_value = mnmd_bone_get_metabox( $opt, 'global' );
		if ( $option_value === 'global') {
			$option_value = mnmd_bone_get_option( $opt, $default );
		}
		
		return $option_value;
	}
}

/**
 * Get meta box (ACF fields) value.
 */
if ( ! function_exists( 'mnmd_bone_get_metabox' ) ) {
	function mnmd_bone_get_metabox( $selector, $default = NULL, $id = NULL ) {
		if ( function_exists( 'get_field' ) ) {
			$prefix = 'field_mnmd_bone_';
			if ( $id ) {
				return get_field( $prefix . $selector, $id );
			} else {
				return get_field( $prefix . $selector );
			}
		} else {
			return $default;
		}
	}
}

/**
 * Get page layout-related options
 */
if ( ! function_exists( 'mnmd_bone_get_layout_opt' ) ){
	function mnmd_bone_get_layout_opt(){
		// Featured block
		$feat_layout = mnmd_bone_get_option('feat-layout','slider');
		$template = ( strpos($feat_layout, '-') ) ? substr($feat_layout, 0, strpos($feat_layout, '-')) : $feat_layout;
		$fw_feat = ( ($feat_layout == 'slider-cover') || ($feat_layout == 'slider-fw') || ($feat_layout == 'carousel') ) ? true : false;

		// Main
		$sidebar_position = mnmd_bone_get_option('latest_posts_sidebar_position','right');
		$content_layout = mnmd_bone_get_option('latest_posts_layout','list');
		$content_layout_type = ( strpos($content_layout, '-') ) ? substr($content_layout, 0, strpos($content_layout, '-')) : $content_layout;
		if ($content_layout_type === 'alt') {
			$big_post_cycle = mnmd_bone_get_option('latest_posts_big_post_cycle', 4);
		} else {
			$big_post_cycle = 0;
		}
		if (is_author()) {
			$sidebar_position = mnmd_bone_get_option('author_archive_sidebar_position', $sidebar_position);
			$content_layout = mnmd_bone_get_option('author_archive_layout', $content_layout);
			$content_layout_type = ( strpos($content_layout, '-') ) ? substr($content_layout, 0, strpos($content_layout, '-')) : $content_layout;
			if ($content_layout_type === 'alt') {
				$big_post_cycle = mnmd_bone_get_option('author_archive_big_post_cycle', 4);
			} else {
				$big_post_cycle = 0;
			}
		} elseif (is_category()) {
			$sidebar_position = mnmd_bone_get_option('category_archive_sidebar_position', $sidebar_position);
			$content_layout = mnmd_bone_get_option('category_archive_layout', $content_layout);
			$content_layout_type = ( strpos($content_layout, '-') ) ? substr($content_layout, 0, strpos($content_layout, '-')) : $content_layout;
			if ($content_layout_type === 'alt') {
				$big_post_cycle = mnmd_bone_get_option('category_archive_big_post_cycle', 4);
			} else {
				$big_post_cycle = 0;
			}
		} elseif (is_search()) {
			$sidebar_position = mnmd_bone_get_option('search_archive_sidebar_position', $sidebar_position);
			$content_layout = mnmd_bone_get_option('search_archive_layout', $content_layout);
			$content_layout_type = ( strpos($content_layout, '-') ) ? substr($content_layout, 0, strpos($content_layout, '-')) : $content_layout;
			if ($content_layout_type === 'alt') {
				$big_post_cycle = mnmd_bone_get_option('search_archive_big_post_cycle', 4);
			} else {
				$big_post_cycle = 0;
			}
		} elseif (is_tag()) {
			$sidebar_position = mnmd_bone_get_option('tag_archive_sidebar_position', $sidebar_position);
			$content_layout = mnmd_bone_get_option('tag_archive_layout', $content_layout);
			$content_layout_type = ( strpos($content_layout, '-') ) ? substr($content_layout, 0, strpos($content_layout, '-')) : $content_layout;
			if ($content_layout_type === 'alt') {
				$big_post_cycle = mnmd_bone_get_option('tag_archive_big_post_cycle', 4);
			} else {
				$big_post_cycle = 0;
			}
		} elseif (is_archive()) {
			$sidebar_position = mnmd_bone_get_option('archive_sidebar_position', $sidebar_position);
			$content_layout = mnmd_bone_get_option('archive_layout', $content_layout);
			$content_layout_type = ( strpos($content_layout, '-') ) ? substr($content_layout, 0, strpos($content_layout, '-')) : $content_layout;
			if ($content_layout_type === 'alt') {
				$big_post_cycle = mnmd_bone_get_option('archive_big_post_cycle', 4);
			} else {
				$big_post_cycle = 0;
			}
		} elseif (is_singular()) {
			$content_layout = '';
			$single_layout = mnmd_bone_get_single_layout();
			if (($single_layout == 'billboard-fw') || ($single_layout == 'top-wide-fw')) {
				$sidebar_position = 'none';
			} else {
				$sidebar_position = mnmd_bone_get_metabox('post-sidebar-position', '');
				if ($sidebar_position == '') {
					$sidebar_position = mnmd_bone_get_option('single-sidebar-position', 'none');
				}
			}
		}

		$content_class = 'postStream block--'.$content_layout;
		if (($content_layout === 'list') || ($content_layout === 'split') || ($content_layout === 'alt--1') || ($content_layout === 'alt--2') || ($content_layout === 'alt--3')) {
			$content_class .= ' postStream--list';
		}
		if ($content_layout === 'alt--4') {
			$content_class .= ' block--tiles';
		}
		if ($content_layout === 'masonry') {
			$content_class .= ' js-masonry-grid';
		}

		$sticky_sidebar = mnmd_bone_get_option('sticky_sidebar', 'yes');
		$main_class = '';
		$sidebar_class = '';
		if ($sidebar_position === 'right') {
			$main_class .= ' hasRightSidebar';
			$sidebar_class .= ' sidebar--right mt-5 mt-lg-0 ms-lg-5 ps-xxl-4';
		} elseif ($sidebar_position === 'left') {
			$main_class .= ' hasLeftSidebar';
			$sidebar_class .= ' sidebar--left mt-5 mt-lg-0 me-lg-5 pe-xxl-4 order-lg-first';
		} else {
			$main_class .= ' layoutContent--fullwidth';
		}
		if($sticky_sidebar === 'yes') {
			$sidebar_class .= ' js-sticky-sidebar';
		}

		// Pagination
		$pagination_type = mnmd_bone_get_option('latest_posts_pagination','1');
		if (is_archive() || is_search()) {
			$pagination_type = '1';
		}

		$layout_opt = array(
			'main-class' => $main_class,
			'content-layout' => $content_layout,
			'content-class' => $content_class,
			'sidebar-position' => $sidebar_position,
			'sticky-sidebar' => $sticky_sidebar,
			'sidebar-class' => $sidebar_class,
			'pagination-type' => $pagination_type,
			'big-post-cycle' => $big_post_cycle,
		);
		return $layout_opt;
	}
}

/**
 * Create args query for featured block
 */
if ( ! function_exists( 'mnmd_bone_create_ft_args' ) ){
	function mnmd_bone_create_ft_args(){
		$args = array();
		$posts_per_page = 5;
		if (current_user_can('read_private_posts')) {
			$post_status = array('publish', 'private');
		} else {
			$post_status = 'publish';
		}

		// post quantity
		$feat_layout = mnmd_bone_get_option('featured_posts_layout', 'alt');
		switch ($feat_layout) {
			case 'tiles':
				$posts_per_page = 5;
				break;

			case 'alt':
				$posts_per_page = 5;
				break;

			default:
				$posts_per_page = mnmd_bone_get_option('featured_posts_quantity', 5);
				break;
		}

		// create args base on method
		$featured_posts_source = mnmd_bone_get_option('featured_posts_source', '');
		$featured_posts_offset = mnmd_bone_get_option('featured_posts_offset', 0);
		$post_not_in = explode(',', mnmd_bone_get_option('featured_posts_exclude', ''));
		switch ($featured_posts_source) {
			case 'by-ids':
				$post_in = explode(',', mnmd_bone_get_option('featured_posts_include', ''));
				if (!empty($post_in)) {
					$args = array(
						'post_status' => $post_status,
						'posts_per_page'      => $posts_per_page,
						'offset' => $featured_posts_offset,
						'post__in'   => $post_in,
						'ignore_sticky_posts' => 1,
						'orderby'=>'post__in',
					);
				} else {
					$args = false;
				}
				break;

			case 'marked-as-featured':
				$prefix = 'mnmd_bone_';
				$args = array(
					'post_status' => $post_status,
					'posts_per_page'      => $posts_per_page,
					'offset' => $featured_posts_offset,
					'post__not_in'   => $post_not_in,
					'ignore_sticky_posts' => 1,
					'meta_key'   => $prefix.'post_featured',
					'meta_value' => '1',
				);
				break;

			default:
			case 'latest':
				$args = array(
					'post_status' => $post_status,
					'posts_per_page'      => $posts_per_page,
					'offset' => $featured_posts_offset,
					'post__not_in'   => $post_not_in,
					'ignore_sticky_posts' => 1,
					'orderby'   => 'date',
				);
				break;
		}

		return $args;
	}
}

/**
 * Get template base on layout
 */
if ( !function_exists('mnmd_bone_get_template') ){
	function mnmd_bone_get_template( $layout = 'list', $post_pos = null, $post_id = null ) {
		global $mnmd_bone_opt;
		$sidebar_position = mnmd_bone_get_option('latest_posts_sidebar_position', 'left');
		if (is_attachment()) {
			$sidebar_position = mnmd_bone_get_option('latest_posts_sidebar_position', $sidebar_position);
		} elseif (is_author()) {
			$sidebar_position = mnmd_bone_get_option('author_archive_sidebar_position', $sidebar_position);
		} elseif (is_category()) {
			$sidebar_position = mnmd_bone_get_option('category_archive_sidebar_position', $sidebar_position);
		} elseif (is_search()) {
			$sidebar_position = mnmd_bone_get_option('search_archive_sidebar_position', $sidebar_position);
		} elseif (is_tag()) {
			$sidebar_position = mnmd_bone_get_option('tag_archive_sidebar_position', $sidebar_position);
		} elseif (is_archive()) {
			$sidebar_position = mnmd_bone_get_option('other_archive_sidebar_position', $sidebar_position);
		}

		switch ( $layout ) {

			case 'tiles':
				$thumb_size = 'mnmd_bone_lg';
				if ($sidebar_position === 'none') {
					echo '<div class="tile-item col-12 col-md-6 col-xxl-4">';
				} else {
					echo '<div class="tile-item col-12 col-xxl-6">';
				}
				set_query_var('thumb_size', $thumb_size);
				get_template_part( 'templates/post-tile' );
				echo '</div>';
				break;

			case 'masonry':
				$thumb_size = 'mnmd_bone_sm';
				if ($sidebar_position === 'none') {
					echo '<div class="grid-item col-12 col-md-6 col-lg-4">';
				} else {
					echo '<div class="grid-item col-12 col-md-6">';
				}
				set_query_var('thumb_size', $thumb_size);
				get_template_part( 'templates/post-card-paper' );
				echo '</div>';
				break;

			default:
			case 'list':
				echo '<div class="postStream-item">';
				get_template_part( 'templates/post-list' );
				echo '</div>';
				break;

			case 'split':
				echo '<div class="postStream-item">';
				get_template_part( 'templates/post-split' );
				echo '</div>';
				break;

			case 'alt--1':
				$big_post_cycle = mnmd_bone_get_option('latest_posts_big_post_cycle', 5);
				$big_post_first = mnmd_bone_get_option('latest_posts_big_post_first', 'yes');
				$format = mnmd_bone_get_post_format();
				$format_allowed = in_array($format, array( 'audio', 'video', 'gallery', 'image', '' ));
				global $wp_query;
				if (!$post_pos) {
					$post_pos = $wp_query->current_post + 1;
				}
				echo '<div class="postStream-item">';
				if ($big_post_first === 'yes') {
					if (($post_pos - 1) % $big_post_cycle) {
						get_template_part( 'templates/post-list' );
					} else {
						if ($format_allowed) {
							get_template_part( 'templates/post-split' );
						} else {
							get_template_part( 'templates/post-list' );
						}
					}
				} else {
					if (($post_pos % $big_post_cycle) === 0) {
						if (has_post_thumbnail() && $format_allowed) {
							get_template_part( 'templates/post-split' );
						} else {
							get_template_part( 'templates/post-list' );
						}
					} else {
						get_template_part( 'templates/post-list' );
					}
				}
				
				echo '</div>';
				break;

			case 'alt--2':
				$big_post_cycle = mnmd_bone_get_option('latest_posts_big_post_cycle', 5);
				$big_post_first = mnmd_bone_get_option('latest_posts_big_post_first', 'yes');
				$format = mnmd_bone_get_post_format();
				$format_allowed = in_array($format, array( 'audio', 'video', 'gallery', 'image', '' ));
				global $wp_query;
				if (!$post_pos) {
					$post_pos = $wp_query->current_post + 1;
				}
				echo '<div class="postStream-item">';
				if ($big_post_first === 'yes') {
					if (($post_pos - 1) % $big_post_cycle) {
						get_template_part( 'templates/post-list' );
					} else {
						if (has_post_thumbnail() && $format_allowed) {
							get_template_part( 'templates/post-tile-large' );
						} else {
							get_template_part( 'templates/post-list' );
						}
					}
				} else {
					if (($post_pos % $big_post_cycle) === 0) {
						if (has_post_thumbnail() && $format_allowed) {
							get_template_part( 'templates/post-tile-large' );
						} else {
							get_template_part( 'templates/post-list' );
						}
					} else {
						get_template_part( 'templates/post-list' );
					}
				}
				echo '</div>';
				break;

			case 'alt--3':
				$big_post_cycle = mnmd_bone_get_option('latest_posts_big_post_cycle', 5);
				$big_post_first = mnmd_bone_get_option('latest_posts_big_post_first', 'yes');
				$format = mnmd_bone_get_post_format();
				$format_allowed = in_array($format, array( 'audio', 'video', 'gallery', 'image', '' ));
				global $wp_query;
				if (!$post_pos) {
					$post_pos = $wp_query->current_post + 1;
				}
				echo '<div class="postStream-item">';
				if ($big_post_first === 'yes') {
					if (($post_pos - 1) % $big_post_cycle) {
						get_template_part( 'templates/post-list' );
					} else {
						if (has_post_thumbnail() && $format_allowed) {
							get_template_part( 'templates/post-cutout' );
						} else {
							get_template_part( 'templates/post-list' );
						}
					}
				} else {
					if (($post_pos % $big_post_cycle) === 0) {
						if (has_post_thumbnail() && $format_allowed) {
							get_template_part( 'templates/post-cutout' );
						} else {
							get_template_part( 'templates/post-list' );
						}
					} else {
						get_template_part( 'templates/post-list' );
					}
				}					
				echo '</div>';
				break;
		}
	}
}

/**
 * Check post format
 */
if ( !function_exists('mnmd_bone_get_post_format') ){
	function mnmd_bone_get_post_format( $post_id = '' ) {
		$format = get_post_format($post_id);
		switch ($format) {

			case 'video':
				$format_media = mnmd_bone_get_metabox('post_format_video_url');
				if ($format_media) {
					return $format;
				} else {
					return '';
				}
				break;

			case 'audio':
				$embed = mnmd_bone_get_metabox( 'post_format_audio_url' );
				$audio_files = mnmd_bone_get_metabox( 'post_format_audio_file' );
				if ($embed  || $audio_files) {
					return $format;
				} else {
					return '';
				}
				break;

			case 'image':
				$format_media = mnmd_bone_get_metabox( 'post_format_image_file' );
				if ($format_media) {
					return $format;
				} else {
					return '';
				}
				break;

			case 'gallery':
				$format_media = mnmd_bone_get_metabox( 'post_format_gallery_files' );
				if ($format_media) {
					return $format;
				} else {
					return '';
				}
				break;

			case 'link':
				$format_media = mnmd_bone_get_metabox( 'format_link_url' );
				if ($format_media === '') {
					return '';
				} else {
					return $format;
				}
				break;

			case 'quote':
				$format_media = mnmd_bone_get_metabox( 'format_quote_content' );
				if ($format_media === '') {
					return '';
				} else {
					return $format;
				}
				break;

			default:
				return $format;
				break;
		}
	}
}

/**
 * Display post format media
 */
if ( !function_exists('mnmd_bone_post_format') ){
	function mnmd_bone_post_format( $thumb_size = 'mnmd_bone_sm', $class = '' ) {
		?>
		<div class="postFeaturedMedia<?php if ( is_single() ) echo ' postFeaturedMedia--single'; ?><?php if ($class !== '') echo ' '.esc_attr($class); ?>">
		<?php
		$format = mnmd_bone_get_post_format();
		switch ($format) {

			case 'video':
				get_template_part( 'templates/format-video' );
				break;

			case 'audio':
				get_template_part( 'templates/format-audio' );
				break;

			case 'image':
				get_template_part( 'templates/format-image' );
				break;

			case 'gallery':
				get_template_part( 'templates/format-gallery' );
				break;

			case 'link':
				get_template_part( 'templates/format-link' );
				break;

			case 'quote':
				get_template_part( 'templates/format-quote' );
				break;

			case 'aside':
				return;
				break;

			default:
				mnmd_bone_featured_img( $thumb_size );
				break;
		}
		?>
		</div>
		<?php
	}
}

/**
 * Display post featured image
 */
if ( !function_exists('mnmd_bone_featured_img') ){
	function mnmd_bone_featured_img( $size = 'mnmd_bone_sm', $class = '', $icon = false ) {
		if ( !has_post_thumbnail() )
			return;
		
		$article_link = get_permalink(); ?>
		<div class="postFeaturedImg<?php if ( is_single() ) echo ' postFeaturedImg--single'; ?><?php if ($class != '') echo ' '.esc_attr($class); ?>">
			<?php if ( !is_single() ) { ?>
			<a href="<?php echo esc_url($article_link); ?>" class="o-blockLink">
				<?php if ($icon) { mnmd_bone_format_icon(); } ?>
				<?php the_post_thumbnail($size); ?>
			</a>
			<?php } else {
				the_post_thumbnail($size);
				$featured_img_caption = mnmd_bone_get_metabox('featured_img_caption');
				if ($featured_img_caption) {
					echo '<div class="postFeaturedImg-caption">'.$featured_img_caption.'</div>';
				}
			} ?>
		</div>
		<?php
	}
}

/**
 * Display post review badge in post title
 */
if ( ! function_exists( 'mnmd_bone_review_score_badge' ) ) {  
	function mnmd_bone_review_score_badge() {
		if ( !function_exists('rwmb_meta') )
			return;
		
		$post_id = get_the_id();
		$review_switch = rwmb_meta( 'mnmd_bone_review_switch', $post_id );
		if ( $review_switch != '1' ) return;
		$review_totalscore = rwmb_meta( 'mnmd_bone_review_totalscore', $post_id );
		$max_score = 10; ?>
		<span class="reviewScoreBadge">
			<i class="fa fa-star"></i>&nbsp;<!--
			--><span><?php echo esc_html($review_totalscore); ?></span><!--
			--><span>/<?php echo esc_html($max_score); ?></span>
		</span>
	<?php
	}
}

/**
 * Display article meta buttons
 */
if ( !function_exists('mnmd_bone_post_meta_btn') ){
	function mnmd_bone_post_meta_btn( $style = '1' ) {
		switch ($style) {
			case '1':
			default:
				?>
				<div class="postMeta--btn postMeta--btn--1">
					<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
						<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
						<?php if ( get_comments_number() != '0' ) { comments_number('0','1','%'); echo '<span class="hidden-xs"> '.esc_html__('comments', 'bone').'</span>'; }
						else { echo '<span class="hidden-xs"> '.esc_html__('Comment', 'bone').'</span>'; } ?>
					</a>
				</div>
				<?php
				break;

			case '2':
				$article_link = get_permalink();
				?>
				<div class="postMeta--btn postMeta--btn--2 clearfix">
					<div class="u-floatLeft">
						<a href="<?php echo esc_url($article_link); ?>" class="readMoreLink metaLink metaFont has-icon-last"><span><?php esc_html_e('Read more', 'bone'); ?></span><?php echo mnmd_bone_svg_icon( array( 'icon' => 'chevron-right' ) ); ?></a>
					</div>
					<div class="u-floatRight">
						<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
							<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
							<?php
							if ( get_comments_number() != '0' ) {
								printf( _nx( '<span class="hidden-xs">%1$s comment</span>', '<span class="hidden-xs">%1$s comments</span>', get_comments_number(), 'comments title', 'bone' ), number_format_i18n( get_comments_number() ) );
							} else {
								echo '<span class="hidden-xs"> '.esc_html__('Comment', 'bone').'</span>';
							} ?>
						</a>
					</div>
				</div>
				<?php
				break;

			case '3':
				$article_link = get_permalink();
				?>
				<div class="postMeta--btn postMeta--btn--3 clearfix">
					<div class="u-floatLeft">
						<a href="<?php echo esc_url($article_link); ?>" class="readMoreLink metaLink metaFont has-icon-last"><span><?php esc_html_e('Read more', 'bone'); ?></span><?php echo mnmd_bone_svg_icon( array( 'icon' => 'chevron-right' ) ); ?></a>
					</div>
					<div class="u-floatRight">
						<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
							<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
							<?php if ( get_comments_number() != '0' ) { comments_number('0','1','%'); } ?>
						</a>
					</div>
				</div>
				<?php
				break;

			case '4':
				$article_link = get_permalink();
				?>
				<div class="postMeta--btn postMeta--btn--2 clearfix">
					<div class="u-floatLeft">
						<a href="<?php echo esc_url($article_link); ?>" class="readMoreLink metaLink metaFont has-icon-last"><span><?php esc_html_e('Read more', 'bone'); ?></span><?php echo mnmd_bone_svg_icon( array( 'icon' => 'chevron-right' ) ); ?></a>
					</div>
					<div class="u-floatRight">
						<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
							<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
							<?php
							if ( get_comments_number() != '0' ) {
								printf( _nx( '<span class="hidden-xs">%1$s comment</span>', '<span class="hidden-xs">%1$s comments</span>', get_comments_number(), 'comments title', 'bone' ), number_format_i18n( get_comments_number() ) );
							} else {
								echo '<span class="hidden-xs"> '.esc_html__('Comment', 'bone').'</span>';
							} ?>
						</a>
					</div>
				</div>
				<?php
				break;
		}
	}
}

/**
 * Display post footer
 */
if ( !function_exists('mnmd_bone_post_footer') ){
	function mnmd_bone_post_footer( $style = '1' ) {
		switch ($style) {
			case '1':
			default:
				?>
				<div class="postFooter postFooter--1">
					<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
						<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
						<?php if ( get_comments_number() != '0' ) { comments_number('0','1','%'); echo '<span class="hidden-xs"> '.esc_html__('comments', 'bone').'</span>'; }
						else { echo '<span class="hidden-xs"> '.esc_html__('Comment', 'bone').'</span>'; } ?>
					</a>
				</div>
				<?php
				break;

			case '2':
				$article_link = get_permalink();
				?>
				<div class="postFooter postFooter--2 d-flex flex-wrap justify-content-between">
					<div class="me-2">
						<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first"><?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) );
							if ( get_comments_number() != '0' ) {
								printf( _nx( '<span class="hidden-xs">%1$s comment</span>', '<span class="hidden-xs">%1$s comments</span>', get_comments_number(), 'comments title', 'bone' ), number_format_i18n( get_comments_number() ) );
							} else {
								echo '<span class="hidden-xs"> '.esc_html__('Comment', 'bone').'</span>';
							} ?></a>
					</div>
					<div class="ms-2">
						<a href="<?php echo esc_url($article_link); ?>" class="readMoreLink metaLink metaFont has-icon-last"><span><?php esc_html_e('Read more', 'bone'); ?></span><?php echo mnmd_bone_svg_icon( array( 'icon' => 'chevron-right' ) ); ?></a>
					</div>
				</div>
				<?php
				break;

			case '3':
				$article_link = get_permalink();
				?>
				<div class="postMeta--btn postMeta--btn--3 clearfix">
					<div class="u-floatLeft">
						<a href="<?php echo esc_url($article_link); ?>" class="readMoreLink metaLink metaFont has-icon-last"><span><?php esc_html_e('Read more', 'bone'); ?></span><?php echo mnmd_bone_svg_icon( array( 'icon' => 'chevron-right' ) ); ?></a>
					</div>
					<div class="u-floatRight">
						<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
							<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
							<?php if ( get_comments_number() != '0' ) { comments_number('0','1','%'); } ?>
						</a>
					</div>
				</div>
				<?php
				break;

			case '4':
				$article_link = get_permalink();
				?>
				<div class="postMeta--btn postMeta--btn--2 clearfix">
					<div class="u-floatLeft">
						<a href="<?php echo esc_url($article_link); ?>" class="readMoreLink metaLink metaFont has-icon-last"><span><?php esc_html_e('Read more', 'bone'); ?></span><?php echo mnmd_bone_svg_icon( array( 'icon' => 'chevron-right' ) ); ?></a>
					</div>
					<div class="u-floatRight">
						<a href="<?php comments_link(); ?>" class="metaFont metaLink has-icon-first">
							<?php echo mnmd_bone_svg_icon( array( 'icon' => 'comment' ) ); ?>
							<?php
							if ( get_comments_number() != '0' ) {
								printf( _nx( '<span class="hidden-xs">%1$s comment</span>', '<span class="hidden-xs">%1$s comments</span>', get_comments_number(), 'comments title', 'bone' ), number_format_i18n( get_comments_number() ) );
							} else {
								echo '<span class="hidden-xs"> '.esc_html__('Comment', 'bone').'</span>';
							} ?>
						</a>
					</div>
				</div>
				<?php
				break;
		}
	}
}

/**
 * Display post author and date meta
 */
if ( !function_exists('mnmd_bone_post_meta_author') ){
	function mnmd_bone_post_meta_author( $type = '2', $size = 36 ) {
		if ( $type == '1') {
		?>
		<div class="postMeta--author postMeta--author--1 vcard author d-flex align-items-center">
			<div class="postMeta--author-avatar photo flex-shrink-0 me-2"><?php echo get_avatar( get_the_author_meta( 'ID' ), $size, '', esc_html__( 'avatar', 'bone' ) ); ?></div>
			<div class="postMeta--author-text flex-grow-1">
				<span class="postMeta--author-author metaFont fn"><?php the_author_posts_link(); ?></span><span class="middot">&middot;</span><span class="metaText metaDate"><abbr class="published updated" title="<?php the_time(get_option( 'date_format' )); ?>"><?php mnmd_bone_human_datetime(); ?></abbr></span>
			</div>
		</div>
		<?php
		} elseif ( $type == '2') {
		?>
		<div class="postMeta--author postMeta--author--2 o-media vcard author">
			<div class="postMeta--author-avatar o-media-left o-media--middle photo"><?php echo get_avatar( get_the_author_meta( 'ID' ), $size, '', esc_html__( 'avatar', 'bone' ) ); ?></div>
			<div class="postMeta--author-text o-media-body o-media--middle">
				<div class="postMeta--author-author metaFont fn"><?php the_author_posts_link(); ?></div>
				<span class="metaText metaDate"><abbr class="published updated" title="<?php the_time(get_option( 'date_format' )); ?>"><?php mnmd_bone_human_datetime(); ?></abbr></span>	
			</div>
		</div>
		<?php
		} elseif ( $type == '3') {
		?>
		<div class="postMeta--author postMeta--author--3 o-media vcard author">
			<div class="postMeta--author-avatar o-media-left o-media--middle photo"><?php echo get_avatar( get_the_author_meta( 'ID' ), $size, '', esc_html__( 'avatar', 'bone' ) ); ?></div>
			<div class="postMeta--author-text o-media-body o-media--middle">
				<div class="postMeta--author-author metaFont fn"><?php the_author_posts_link(); ?></div>
			</div>
		</div>
		<?php
		} else {
		?>
		<div class="postMeta--author postMeta--author--4 o-media vcard author">
			<div class="postMeta--author-avatar o-media-left o-media--middle photo"><?php echo get_avatar( get_the_author_meta( 'ID' ), $size, '', esc_html__( 'avatar', 'bone' ) ); ?></div>
			<div class="postMeta--author-text o-media-body o-media--middle">
				<span class="metaText--sub"><?php esc_html_e('by', 'bone'); ?></span>
				<div class="postMeta--author-author metaFont fn">
					<?php the_author_posts_link(); ?>
				</div>
			</div>
		</div>
		<?php
		}
	}
}

/**
 * Display post info
 */
if ( !function_exists('mnmd_bone_post_meta') ){
	function mnmd_bone_post_meta( $type = '1' ) {
		switch ( $type ) {
			case '1':
			?>
				<div class="postMeta postMeta--1 d-flex flex-wrap">
					<div class="u-floatLeft">
						<?php mnmd_bone_post_meta_author('2', 32); ?>
					</div>
					
					<div class="u-floatRight">
						<?php echo mnmd_bone_post_meta_btn('1'); ?>
					</div>
				</div>
			<?php
				break;

			case '2':
				if ( !function_exists( 'ADDTOANY_SHARE_SAVE_KIT' ) )
					break;
			?>
				<div class="postMeta postMeta--2 clearfix">
					<div class="flexbox">
						<div class="flexbox-item">
							<?php
							if ( function_exists( 'ADDTOANY_SHARE_SAVE_KIT' ) )
								ADDTOANY_SHARE_SAVE_KIT(); ?>
						</div>
						<div class="flexbox-item">
							<?php
							$link_title = '';
							if ( get_comments_number() != '0' ) {
								$link_title = sprintf( _nx( '%1$s comment', '%1$s comments', get_comments_number(), 'comments title', 'bone' ),	number_format_i18n( get_comments_number() ) );
							} else {
								$link_title = esc_html__('Comment', 'bone');
							} ?>
							<a href="<?php comments_link(); ?>" title="<?php echo esc_attr($link_title); ?>" class="metaFont commentCountBox">
								<?php echo get_comments_number(); ?>
							</a>
						</div>
					</div>
				</div>
			<?php
				break;

			case '3':
			?>
				<div class="postMeta postMeta--3 d-flex flex-wrap justify-content-between">
					<div class="postMeta-author">
						<?php mnmd_bone_post_meta_author('4', 40); ?>
					</div>
					<div class="postMeta-date text-start">
						<span class="metaText--sub"><?php esc_html_e('posted on', 'bone'); ?></span>
						<div class="metaFont metaDate"><abbr class="published updated" title="<?php the_time(get_option( 'date_format' )); ?>"><?php echo get_the_date(); ?></abbr></div>	
					</div>
					<div class="postMeta-comments">
						<?php
						$link_title = '';
						if ( get_comments_number() != '0' ) {
							$link_title = sprintf( _nx( '%1$s comment', '%1$s comments', get_comments_number(), 'comments title', 'bone' ),	number_format_i18n( get_comments_number() ) );
						} else {
							$link_title = esc_html__('Comment', 'bone');
						} ?>
						<a href="<?php comments_link(); ?>" title="<?php echo esc_attr($link_title); ?>" class="metaFont commentCountBox">
							<?php echo get_comments_number(); ?>
						</a>
					</div>
				</div>
			<?php
				break;

			case '4':
			default:
			?>
				<div class="postMeta postMeta--4 clearfix">
					<?php mnmd_bone_post_meta_author('1', 24); ?>
					&middot;
					<a href="<?php comments_link(); ?>" class="metaFont">
						<i class="fa fa-comment"></i>
						<?php
						if ( get_comments_number() != '0' ) {
							printf( _nx( ' %1$s<span class="hidden-xs"> comment</span>', ' %1$s<span class="hidden-xs"> comments</span>', get_comments_number(), 'comments title', 'bone' ), number_format_i18n( get_comments_number() ) );
						} else {
							echo '<span class="hidden-xs"> '.__('Comment', 'bone').'</span>';
						} ?>
					</a>
				</div>
			<?php
				break;
		}
	}
}

/**
 * Display post format icon
 */
if ( !function_exists('mnmd_bone_format_icon') ){
	function mnmd_bone_format_icon(){
		$format = get_post_format();
		switch ($format) {
			case 'video':
				echo '<div class="postFormatIcon formatVideoIcon">' . mnmd_bone_svg_icon( array( 'icon' => 'play' ) ) . '</div>';
				break;

			case 'image':
				echo '<div class="postFormatIcon formatImageIcon">' . mnmd_bone_svg_icon( array( 'icon' => 'image' ) ) . '</div>';
				break;

			case 'gallery':
				echo '<div class="postFormatIcon formatGalleryIcon">' . mnmd_bone_svg_icon( array( 'icon' => 'filter' ) ) . '</div>';
				break;

			case 'audio':
				echo '<div class="postFormatIcon formatAudioIcon">' . mnmd_bone_svg_icon( array( 'icon' => 'audio' ) ) . '</div>';
				break;
			default:
				break;
		}
	}
}

/**
 * Display post categories
 */
if ( !function_exists('mnmd_bone_post_categories') ){
	function mnmd_bone_post_categories($post_id = NULL) {
		$categories = get_the_category( $post_id );
		
		if ( $categories ) {
			$categories = array_slice($categories, 0, 4);
			echo '<ul class="postCategories list-inline">';
			foreach ( $categories as $category ) {
				echo '<li>';
					echo '<a class="postCategory" href="'.get_category_link( $category->term_id ).'" title="'.esc_attr( sprintf( esc_html__( "View all posts in %s", 'bone' ), $category->name ) ) . '" rel="tag">'.$category->cat_name.'</a>';
				echo '</li>';
			}
			echo '</ul>';
		}
	}
}

/**
 * Display first post category
 */
if ( !function_exists('mnmd_bone_post_category') ){
	function mnmd_bone_post_category($post_id = NULL) {
		$category_array = get_the_category($post_id);
		$category_link = NULL;
		if ( $category_array ) {
			$category_id = $category_array[0]->term_id;
			$category_name = esc_attr( $category_array[0]->name );
			$category_link = esc_url( get_category_link( $category_id ) );
		}
		
		if ( $category_link ) {
			echo '<a href="'.$category_link.'" title="'.esc_html__('View all posts in', 'bone').' '.$category_name.'" rel="tag" class="postCategory">'.$category_name.'</a>';
		}
	}
}

/**
 * Display post tags
 */
if ( !function_exists('mnmd_bone_post_tags') ){
	function mnmd_bone_post_tags($post_id = NULL) {
		$tags = get_the_tags( $post_id );
		if ( $tags ) {
			$tags = array_slice($tags, 0, 8);
			$output = '<div class="postTags metaFont">';
			$output .= '<div class="postTags-list clearfix">';
			foreach ( $tags as $tag ) {
					$output .= '<a class="postTag metaFont" href="'.get_tag_link( $tag->term_id ).'" title="'.esc_attr( sprintf( esc_html__( "View all posts in %s", 'bone' ), $tag->name ) ) . '" rel="tag">'.$tag->name.'</a>';
			}
			$output .= '</div>';
			$output .= '</div>';
		} else {
			$output = false;
		}

		return $output;
	}
}

/**
 * Post pagination
 */
if ( !function_exists('mnmd_bone_post_pagination') ){
	function mnmd_bone_post_pagination() {
		wp_link_pages( array(
			'before'      => '<div class="postPagination metaFont"><span class="postPagination-title">' . esc_html__( 'Pages:', 'bone' ) . '</span>',
			'after'       => '</div>',
			'link_before' => '<span>',
			'link_after'  => '</span>',
			'pagelink'    => '<span class="sr-only">' . esc_html__( 'Page', 'bone' ) . ' </span>%',
			'separator'   => '<span class="sr-only">, </span>',
		) );
	}
}

/**
 * Get pagination base on type
 */
if ( !function_exists('mnmd_bone_get_pagination') ){
	function mnmd_bone_get_pagination( $pagination_type = '1' ) {
		global $wp_query;
		switch ( $pagination_type ) {
			case '1':
			default:
				mnmd_bone_pagination( $wp_query );
				break;
			case '2':
				mnmd_bone_pagination_compact();
				break;
			case '3':
				echo '<div class="pagePagination pagePagination--loadMore metaFont">';
				echo '<div class="loadMoreBtn btn btn--pill btn-lg has-icon-last metaFont js-ajax-loadmore is-active"><span class="loadMoreBtn-text">' . esc_html__('Load more', 'bone').'</span>' . mnmd_bone_svg_icon( array( 'icon' => 'reload' ) ) . '</div>';
				echo '</div>';
				break;
			case '4':
				echo '<div class="pagePagination pagePagination--infiniteScroll metaFont">';
				echo '<div class="loadMoreBtn btn btn--pill btn-lg has-icon-last metaFont js-ajax-infinity-scroll is-active"><span class="loadMoreBtn-text">' . esc_html__('Load more', 'bone') . '</span>' . mnmd_bone_svg_icon( array( 'icon' => 'reload' ) ) . '</div>';
				echo '</div>';
				break;
		}
	}
}

/**
 * Site pagination: compact type
 */
if ( !function_exists('mnmd_bone_pagination_compact') ){
	function mnmd_bone_pagination_compact() {
		?>
		<div class="pagePagination pagePagination--compact metaFont">
			<?php
			if ( get_previous_posts_link() ) {
			?>
				<div class="newerPosts"><?php previous_posts_link( esc_html__('Newer Posts', 'bone') ); ?></div>
			<?php
			}

			if ( get_next_posts_link() ) {
			?>
				<div class="olderPosts"><?php next_posts_link( esc_html__('Older Posts', 'bone') ); ?></div>
			<?php
			}
			?>
			
			
		</div>
		<?php
	}
}

/**
 * Site pagination: standard type
 */
if ( !function_exists('mnmd_bone_pagination') ){
	function mnmd_bone_pagination( $query ){  
		if ( $query->max_num_pages > 1 ) {
			echo '<div class="pagePagination metaFont">';
			echo '<div class="pagePagination-wrap">';
			$query->query_vars['paged'] > 1 ? $current = $query->query_vars['paged'] : $current = 1;
			$big = 999999999;
			$pagination = array(
				'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
				'format' => '?paged=%#%',
				'total' => $query->max_num_pages,
				'current' => $current,
				'prev_text' => esc_html__( 'Previous', 'bone' ),
				'next_text' => esc_html__( 'Next', 'bone' ),
				'type' => 'plain'
			);
			echo paginate_links( $pagination );
			echo '</div>';
			echo '</div>';
		}
	}
}

/**
 * Get post single layout
 */
if ( !function_exists('mnmd_bone_get_single_layout') ){
	function mnmd_bone_get_single_layout() {
		$single_layout = mnmd_bone_get_metabox( 'post_header_layout', 'global' );
		if ($single_layout === 'global') {
			$single_layout = mnmd_bone_get_option('single_post_header_style', 'default');
		}
		$format = get_post_format();
		if ( ( $format && ($single_layout === 'cover') ) || ( (!has_post_thumbnail()) && ($single_layout === 'cover') ) ) {
			$single_layout = 'default';
		} elseif ($format && has_post_thumbnail()) {
			$thumb_id = get_post_thumbnail_id();
			$thumb_data = wp_get_attachment_image_src( $thumb_id, 'full' );
			$thumb_width = $thumb_data[1];
			$thumb_height = $thumb_data[2];
			if ($thumb_width > 0) {
				if (($thumb_width < 350) && (($thumb_height / $thumb_width) > 1.5)) {
					$single_layout = 'default';
				}
			}
		}

		return $single_layout;
	}
}

/**
 * Post single schema meta
 */
if ( !function_exists('mnmd_bone_single_schema_meta') ){
	function mnmd_bone_single_schema_meta($post_id = '') {
		$review_switch = mnmd_bone_get_metabox('review_switch', '0');
		if ($review_switch === '1') {
			if (function_exists('rwmb_meta')) {
				$review_scores = rwmb_meta( 'mnmd_bone_review_score', $post_id );
				$review_totalscore = rwmb_meta( 'mnmd_bone_review_totalscore', $post_id );
				$review_summary = mnmd_bone_truncate(rwmb_meta( 'mnmd_bone_review_summary', $post_id ), 180);
				$review_pros = rwmb_meta( 'mnmd_bone_review_pros', $post_id );
				$review_cons = rwmb_meta( 'mnmd_bone_review_cons', $post_id );
				$max_score = 10;
			} else {
				$review_switch = '0';
			}
		}
		
		$thumbnail_src = wp_get_attachment_image_src(get_post_thumbnail_id(), 'mnmd_bone_sm');
		$site_logo = mnmd_bone_get_option('logo', NULL);
		$site_logo_url = '';
		if ( $site_logo !== NULL ) {
			if ( ( array_key_exists( 'url', $site_logo ) ) && ( $site_logo['url'] !== '' ) ) {
				$site_logo_url = $site_logo['url'];
			}
		}
		$author_name = get_the_author();
		$publisher_name = get_bloginfo('name');
		if (empty($publisher_name)){
			$publisher_name = $author_name;
		}
		$description = get_the_excerpt();

		if ($review_switch !== '1') { ?>
			<script type="application/ld+json">
				{
					"@context": "http://schema.org/",
					"@type": "BlogPosting",
					"mainEntityOfPage": {
						"@type": "WebPage",
						"@id": "<?php echo esc_url(get_permalink()); ?>"
					},
					"headline": "<?php echo esc_attr(get_the_title()); ?>",
					"image": [
						"<?php echo esc_url($thumbnail_src[0]); ?>"
					],
					"datePublished": "<?php echo get_the_time('c'); ?>",
					"dateModified": "<?php echo get_the_modified_time('c'); ?>",
					"author": {
						"@type": "Person",
						"name": "<?php echo esc_attr($author_name); ?>"
					},
					"publisher": {
						"@type": "Organization",
						"name": "<?php echo esc_attr($publisher_name); ?>",
						"logo": {
							"@type": "ImageObject",
							"url": "<?php echo esc_url($site_logo_url); ?>"
						}
					},
					"description": "<?php echo esc_html($description); ?>"
				}
			</script>
			<?php
			} else { ?>
			<script type="application/ld+json">
				{
					"@context": "http://schema.org/",
					"@type": "Review",
					"name": "<?php echo esc_attr(get_the_title()); ?>",
					"itemReviewed": {
						"@type": "Thing",
						"name": "<?php echo esc_attr(get_the_title()); ?>"
					},
					"datePublished": "<?php echo get_the_time('c'); ?>",
					"author": {
						"@type": "Person",
						"name": "<?php echo esc_attr($author_name); ?>"
					},
					"publisher": {
						"@type": "Organization",
						"name": "<?php echo esc_attr($publisher_name); ?>",
						"logo": {
							"@type": "ImageObject",
							"url": "<?php echo esc_url($site_logo_url); ?>"
						}
					},
					"description": "<?php echo esc_html($review_summary); ?>",
					"reviewBody": "<?php echo esc_html($review_summary); ?>",
					"reviewRating": {
						"@type": "Rating",
						"worstRating": "1",
						"bestRating": "<?php echo esc_attr($max_score); ?>",
						"ratingValue": "<?php echo esc_attr($review_totalscore); ?>"
					}
				}
			</script>
		<?php
		}
	}
}

/**
 * Display post single header
 */
if ( !function_exists('mnmd_bone_single_header') ){
	function mnmd_bone_single_header( $style = 'default' ) {
		$bone_format = mnmd_bone_get_post_format();
		if ( ( $style === 'cover' ) && ( !has_post_thumbnail() || $bone_format ) ) {
			$style = 'default';
		} elseif ( ( $style === 'cover-fullwidth' ) && ( !has_post_thumbnail() || $bone_format ) ) {
			$style = 'default-fullwidth';
		}

		switch ($style) {
			default:
			case 'default':
				if ( $bone_format ) {
					mnmd_bone_post_format('mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5');
				} else {
					mnmd_bone_featured_img('mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5 shadow-6');
				}
				?>
				<header class="postSingle-header mb-3 mb-sm-5">
					<?php mnmd_bone_post_categories(); ?>
					<h1 class="postTitle entry-title display-5"><?php the_title(); ?></h1>
					<?php mnmd_bone_post_meta('3'); ?>
				</header>
				<?php
				break;

			case 'default-fullwidth':
				?>
				<div class="container">
					<?php
					if ( $bone_format ) {
						mnmd_bone_post_format( 'mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5' );
					} else {
						mnmd_bone_featured_img('mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5 shadow-6');
					}
					?>
					<header class="postSingle-header postSingle-header--wide postSingle-header--big mb-3 mb-sm-5 text-center">
						<?php mnmd_bone_post_categories(); ?>
						<h1 class="postTitle entry-title display-4"><?php the_title(); ?></h1>
						<div class="contentConstraint">
							<?php mnmd_bone_post_meta('3'); ?>
						</div>
					</header>
				</div>
				<?php
				break;

			case 'title-top':
				?>
				<header class="postSingle-header mb-3 mb-sm-5">
					<?php mnmd_bone_post_categories(); ?>
					<h1 class="postTitle entry-title display-5"><?php the_title(); ?></h1>
					<?php mnmd_bone_post_meta('3'); ?>
				</header>
				<?php
				if ( $bone_format ) {
					mnmd_bone_post_format('mnmd_bone_xl', 'mb-3 mb-lg-5');
				} else {
					mnmd_bone_featured_img('mnmd_bone_xl', 'mb-3 mb-lg-5 shadow-6');
				}
				break;

			case 'title-top-fullwidth':
				?>
				<div class="container">
					<header class="postSingle-header postSingle-header--wide postSingle-header--big mt-3 mt-sm-5 mb-3 mb-sm-5">
						<div class="contentConstraint text-center">
							<?php mnmd_bone_post_categories(); ?>
							<h1 class="postTitle entry-title display-4"><?php the_title(); ?></h1>
							<?php mnmd_bone_post_meta('3'); ?>
						</div>
					</header>
					<?php
					if ( $bone_format ) {
						mnmd_bone_post_format( 'mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5' );
					} else {
						mnmd_bone_featured_img('mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5 shadow-6');
					}
					?>
				</div>
				<?php
				break;

			case 'cover':
				mnmd_bone_single_cover();
				break;

			case 'cover-fullwidth':
				mnmd_bone_single_billboard();
				break;

			case 'no-featured-image':
				if ( $bone_format ) {
					mnmd_bone_post_format('mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5');
				}
				?>
				<header class="postSingle-header mb-3 mb-sm-5">
					<?php mnmd_bone_post_categories(); ?>
					<h1 class="postTitle entry-title display-5"><?php the_title(); ?></h1>
					<?php mnmd_bone_post_meta('3'); ?>
				</header>
				<?php
				break;

			case 'no-featured-image-fullwidth':
				?>
				<div class="container">
					<?php
					if ( $bone_format ) {
						mnmd_bone_post_format( 'mnmd_bone_xl', 'mt-3 mt-sm-5 mb-3 mb-lg-5' );
					}
					?>
					<header class="postSingle-header postSingle-header--wide postSingle-header--big mt-3 mt-sm-5 mb-3 mb-sm-5 text-center">
						<?php mnmd_bone_post_categories(); ?>
						<h1 class="postTitle entry-title display-4"><?php the_title(); ?></h1>
						<div class="contentConstraint">
							<?php mnmd_bone_post_meta('3'); ?>
						</div>
					</header>
				</div>
				<?php
				break;
		}
	}
}

/**
 * Display post single billboard
 */
if ( !function_exists('mnmd_bone_single_billboard') ){
	function mnmd_bone_single_billboard() {
		if ( !has_post_thumbnail() )
			return;

		$parallax = mnmd_bone_get_single_option( 'single_post_billboard_parallax', 'yes' );
		$thumb_size = 'mnmd_bone_cover'; ?>
		<div class="postSingle--billboard-cover m-lg-4 shadow-5<?php if ($parallax !== 'yes') echo ' is-parallaxDisabled'; ?>">
			<div id="md-single-cover" class="postSingle--billboard-cover-bgImg" <?php mnmd_bone_inline_css_background_img($thumb_size); ?>></div>
			
			<div class="postSingle--billboard-cover-wrapper d-flex align-items-center">
				<div class="postSingle--billboard-cover-inner p-2 p-lg-4">
					<div class="container">
						<div class="postInfo overlayInfo text-center">
							<div id="md-billboard-info" class="postSingle-header postSingle-header--billboard postSingle-header--big">
								<?php mnmd_bone_post_categories(); ?>
								<h1 class="postTitle entry-title display-4"><?php the_title(); ?></h1>
								<div class="contentConstraint">
									<?php mnmd_bone_post_meta('3'); ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
}

/**
 * Display post single cover
 */
if ( !function_exists('mnmd_bone_single_cover') ) {
	function mnmd_bone_single_cover() {
		if ( !has_post_thumbnail() )
			return;

		$thumb_size = 'mnmd_bone_xl';
		?>
			<div class="postSingle-cover">
				<div class="o-backgroundImg o-backgroundImg--dimmed" <?php mnmd_bone_inline_css_background_img($thumb_size); ?>></div>
				<div class="postSingle-cover-wrapper d-flex align-items-end">
					<div class="postSingle-cover-inner flex-grow-1 p-4 p-md-5">
						<div class="postInfo overlayInfo">
							<div class="postSingle-header">
								<?php mnmd_bone_post_categories(); ?>
								<h1 class="postTitle entry-title"><?php the_title(); ?></h1>
								<?php mnmd_bone_post_meta('3'); ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		<?php
	}
}

/**
 * Display post single footer
 */
if ( !function_exists('mnmd_bone_single_footer') ){
	function mnmd_bone_single_footer( $post_id = '' ) { 
		if ( (mnmd_bone_post_tags($post_id)) || (function_exists( 'ADDTOANY_SHARE_SAVE_KIT' )) ) {
		?>
		<footer class="postFooter postFooter--single">
			<div class="row flex-wrap">
				<?php
				if (mnmd_bone_post_tags($post_id)) { ?>
					<div class="row col-sm-6">
						<div class="postFooter-tags">
						<?php echo mnmd_bone_post_tags($post_id); ?>
						</div>
					</div>
				<?php
				} ?>

				<?php
				if ( function_exists( 'ADDTOANY_SHARE_SAVE_KIT' ) ) { ?>
					<div class="row col-sm-6">
						<div class="postFooter-share">
							<?php ADDTOANY_SHARE_SAVE_KIT(); ?>
						</div>
					</div>
				<?php
				} ?>
			</div>
		</footer>
		<?php
		}
	}
}

/**
 * Display post review box
 */
if ( ! function_exists( 'mnmd_bone_review_score' ) ) {  
	 function mnmd_bone_review_score() {
		if ( !function_exists('rwmb_meta') )
			return;
		
		$post_id = get_the_id();
		$review_switch = rwmb_meta( 'mnmd_bone_review_switch', $post_id );
		if ( $review_switch != '1' ) return;
		$review_scores = rwmb_meta( 'mnmd_bone_review_score', $post_id );
		$review_totalscore = rwmb_meta( 'mnmd_bone_review_totalscore', $post_id );
		$review_summary = rwmb_meta( 'mnmd_bone_review_summary', $post_id );
		$review_pros = rwmb_meta( 'mnmd_bone_review_pros', $post_id );
		$review_cons = rwmb_meta( 'mnmd_bone_review_cons', $post_id );
		$max_score = 10;?>
		<div class="reviewBox">
			<div class="reviewBox-breakdown">
				<h5><?php esc_html_e('The breakdown', 'bone'); ?></h5>
				<?php if ( ($review_summary != '') && ((!empty($review_pros)) || (!empty($review_cons))) ) { ?>
				<p class="blurb"><?php echo esc_html($review_summary); ?></p>
				<?php } ?>
				<div class="reviewMeter">
		<?php 
		foreach ($review_scores as $review_score) {
			if ( isset( $review_score['criteria_name'] ) && isset( $review_score['criteria_score'] ) ) { ?>
 					<div class="reviewMeter-item clearfix">
						<h5 class="reviewMeter-item-name titleFont"><?php echo esc_html($review_score['criteria_name']); ?></h5>
						<div class="reviewMeter-item-score metaFont"><?php echo esc_html($review_score['criteria_score']).'/'.$max_score; ?></div>
						<div class="progressContainer">
							<div class="progressContainer-bar" style="width:<?php echo (intval($review_score['criteria_score'])*100/$max_score); ?>%"></div>
						</div>
					</div>
				<?php
			}
		} ?>
				</div>
			</div>
			<div class="reviewBox-summary clearfix">
				<div class="reviewBox-summary-totalScore metaFont">
					<div class="reviewBox-summary-totalScore-wrap">
						<div><?php echo esc_html($review_totalscore); ?></div>
						<span><?php esc_html_e('Total score', 'bone'); ?></span>
					</div>
				</div>

				<?php if ( (!empty($review_pros)) || (!empty($review_cons)) ) { ?>
				<div class="reviewBox-summary-prosNCons clearfix">
					
					<?php if ( !empty($review_pros) ) { ?>
					<div class="reviewBox-summary-proList">
						<h5 class="titleFont"><?php esc_html_e('Good', 'bone'); ?></h5>
						<ul>
							<?php foreach ($review_pros as $value) { ?>
							<li><i class="fa fa-plus-square"></i><?php echo esc_html($value); ?></li>
							<?php } ?>
						</ul>
					</div>
					<?php } ?>
					
					<?php if ( !empty($review_cons) ) { ?>
					<div class="reviewBox-summary-conList">
						<h5 class="titleFont"><?php esc_html_e('Bad', 'bone'); ?></h5>
						<ul>
							<?php foreach ($review_cons as $value) { ?>
							<li><i class="fa fa-minus-square"></i><?php echo esc_html($value); ?></li>
							<?php } ?>
						</ul>
					</div>
					<?php } ?>
					
				</div>
				
				<?php } elseif ( $review_summary != '' ) { ?>
				<div class="reviewBox-summary-blurb">
					<p class="blurb"><?php echo esc_html($review_summary); ?></p>	
				</div>
				<?php } ?>
				
			</div>
		</div>
		<?php
	}
}

/**
 * Get related posts
 */
function mnmd_bone_get_related_posts( $post_id, $related_count, $args = array() ) {
	$orderby = mnmd_bone_get_option('single_related_posts_order', 'latest');
	$args = wp_parse_args( (array) $args, array(
		'orderby' => $orderby,
		'return'  => 'query', // Valid values are: 'query' (WP_Query object), 'array' (the arguments array)
	) );

	$post_navigation = mnmd_bone_get_option('postnav-switch', '1');
	if ((is_single()) && ($post_navigation === '1')) {
		$next_post = get_next_post();
		$next_post_ID = (property_exists($next_post, 'ID')) ? $next_post->ID : 0;
		$prev_post = get_previous_post();
		$prev_post_ID = (property_exists($prev_post, 'ID')) ? $prev_post->ID : 0;
	} else {
		$next_post_ID = 0;
		$prev_post_ID = 0;
	}
 
	$related_args = array(
		'post_type'      => get_post_type( $post_id ),
		'posts_per_page' => $related_count,
		'post_status'    => 'publish',
		'post__not_in'   => array( $post_id, $next_post_ID, $prev_post_ID ),
		'orderby'        => $args['orderby'],
		'tax_query'      => array(),
	);
 
	$post       = get_post( $post_id );
	$taxonomies = get_object_taxonomies( $post, 'names' );
 
	foreach( $taxonomies as $taxonomy ) {
		if (($taxonomy === 'tag') || ($taxonomy === 'category')) {
			$terms = get_the_terms( $post_id, $taxonomy );
			if ( empty( $terms ) ) continue;
			$term_list = wp_list_pluck( $terms, 'slug' );
			$related_args['tax_query'][] = array(
				'taxonomy' => $taxonomy,
				'field'    => 'slug',
				'terms'    => $term_list
			);
		}
	}
 
	if( count( $related_args['tax_query'] ) > 1 ) {
		$related_args['tax_query']['relation'] = 'OR';
	}

	if( $args['return'] == 'query' ) {
		return new WP_Query( $related_args );
	} else {
		return $related_args;
	}
}

/**
 * Comment layout
 */
if ( ! function_exists( 'mnmd_bone_comment' ) ) {
	function mnmd_bone_comment($comment, $args, $depth){
		$post = get_post(get_the_ID());
		
		switch ($comment->comment_type):
			case 'pingback':
			case 'trackback':
			?>
			
			<li class="post pingback">
				<p><?php esc_html_e('Pingback:', 'bone'); ?> <?php comment_author_link(); ?><?php if (current_user_can('edit_comment', $comment->comment_ID)) {edit_comment_link(esc_html__('Edit', 'bone'), '<span class="edit-link">', '</span>'); } ?></p>
			<?php
				break;

			default:
			?>
		
			<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
				<article id="comment-<?php comment_ID(); ?>" class="comment">
				
					<div class="comment-header flexbox">

						<div class="comment-avatar flexbox-item">
						<?php
							echo get_avatar($comment, 40);
						?>
						</div>

						<div class="comment-meta flexbox-item">					
							<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>" class="comment-author titleFont">
								<?php comment_author(); ?>
								<?php if ( $comment->user_id === $post->post_author ) { ?>
								<span class="comment-bypostauthor-badge"><?php echo mnmd_bone_svg_icon( array( 'icon' => 'user' ) ); esc_html_e('Author', 'bone'); ?></span>
								<?php } ?>
							</a>
							<a href="<?php comment_link(); ?>" class="comment-time metaText" title="<?php comment_date(); esc_html_e(' at ', 'bone'); comment_time(); ?>">
								<time datetime="<?php comment_time( 'c' ); ?>">
									<?php
										/* translators: 1: comment date, 2: comment time */
										printf( esc_html__( '%1$s at %2$s', 'bone' ), get_comment_date( '', $comment ), get_comment_time() );
									?>
								</time>
							</a>
						</div> <!-- .comment-meta -->

					</div>
		
					<div class="comment-content bodyCopy">
						<?php comment_text(); ?>
						
						<?php if ($comment->comment_approved == '0'): ?>
							<em class="comment-awaiting-moderation"><?php esc_html_e('Your comment is awaiting moderation.', 'bone'); ?></em>
						<?php endif; ?>
					</div>

					<div class="comment-actions">
						<?php
						comment_reply_link(array_merge($args, array(
							'reply_text' => '<span class="metaBtn has-icon-first">' . mnmd_bone_svg_icon( array( 'icon' => 'reply' ) ) . '<span>' . esc_html__( 'Reply', 'bone').'</span></span>',
							'depth'      => $depth,
							'max_depth'  => $args['max_depth']
						))); 
						?>

						<?php if (current_user_can('edit_comment', $comment->comment_ID)): ?>
							<a href="<?php echo get_edit_comment_link(); ?>" class="comment-edit-link metaBtn has-icon-first"><?php echo mnmd_bone_svg_icon( array( 'icon' => 'edit' ) ); ?><span><?php esc_html_e( 'Edit', 'bone' ); ?></span></a>
						<?php endif; ?>
					</div><!-- .reply -->

				</article><!-- #comment-N -->
	
				<?php
				break;
		endswitch;
		
	}
}

/**
 * Display navigation to next/previous comments when applicable.
 */
if ( ! function_exists( 'mnmd_bone_comment_nav' ) ){
	function mnmd_bone_comment_nav() {
		// Are there comments to navigate through?
		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
		?>
		<nav class="navigation comment-navigation">
			<h4 class="sr-only"><?php esc_html_e( 'Comment navigation', 'bone' ); ?></h4>
			<div class="nav-links clearfix">
				<?php
					if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'bone' ) ) ) :
						printf( '<div class="nav-previous"><i class="fa fa-chevron-left"></i>&nbsp;%s</div>', $prev_link );
					endif;

					if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'bone' ) ) ) :
						printf( '<div class="nav-next">%s&nbsp;<i class="fa fa-chevron-right"></i></div>', $next_link );
					endif;
				?>
			</div><!-- .nav-links -->
		</nav><!-- .comment-navigation -->
		<?php
		endif;
	}
}

/**
 * AJAX function to load more post
 */
if ( !function_exists('mnmd_bone_ajax_load_post') ){
	function mnmd_bone_ajax_load_post() {
		$pagination_type = mnmd_bone_get_option('latest_posts_pagination', '1');
		if ( ($pagination_type !== '3') && ($pagination_type !== '4')) {
			return;
		}

		$layout_opt = mnmd_bone_get_layout_opt();
		$loaded_post_count = $_POST['loadedPostsCount'];
		$post_pos = $loaded_post_count + 1;

		$query_vars = $_POST['query_vars'];
		$query_vars['paged'] = $_POST['page'];
		$posts = new WP_Query( $query_vars );

		if( $posts->have_posts() ) { 
			while ( $posts->have_posts() ) { 
				$posts->the_post();
				mnmd_bone_get_template( $layout_opt['content-layout'], $post_pos );
				if (isset($loaded_post_count)) {
					$loaded_post_count++;
					$post_pos = $loaded_post_count + 1;
				}
			}
		}

		die();
	}
}
add_action( 'wp_ajax_nopriv_ajax_load_post', 'mnmd_bone_ajax_load_post' );
add_action( 'wp_ajax_ajax_load_post', 'mnmd_bone_ajax_load_post' );

/**
 * Auto set video thumbnail as featured image
 */
if ( ! function_exists( 'mnmd_bone_auto_set_featured_image') ) {
	function mnmd_bone_auto_set_featured_image($post_id) {
		$format = get_post_format( $post_id );

		if ($format == 'video') { 			// Format video
			$url = mnmd_bone_get_metabox( 'format_video_url', '', $post_id );
			if(!has_post_thumbnail($post_id) && ( $url != '')) { 
				require_once ABSPATH . 'wp-includes/class-oembed.php';
				$oembed = new WP_oEmbed();
				$url_parse = parse_url($url);
				$provider = $oembed->discover($url);
				$video = $oembed->fetch($provider, $url, array('width' => 820, 'height' => 460));
				$thumb = $video->thumbnail_url;

				if ($thumb) {
					media_sideload_image($thumb, $post_id, 'thumbnail image.');
				
					// find the most recent attachment for the given post
					$attachments = get_posts(
						array(
							'post_type' => 'attachment',
							'numberposts' => 1,
							'order' => 'DESC',
							'post_parent' => $post_id
						)
					);
					$attachment = $attachments[0];    
					// and set it as the post thumbnail
					set_post_thumbnail( $post_id, $attachment->ID );
				} else {
					return;
				}
			}
		} elseif ($format == 'audio') { 			// Format audio
			$url = mnmd_bone_get_metabox( 'format_audio_url', '', $post_id );
			if (!has_post_thumbnail($post_id) && ( $url != '')) {
				require_once ABSPATH . 'wp-includes/class-oembed.php';
				$oembed= new WP_oEmbed();
				$provider = $oembed->discover($url);
				$data = $oembed->fetch($provider, $url, array('width' => 820, 'height' => 460));
				$thumb = $data->thumbnail_url;

				if($thumb) {
					media_sideload_image($thumb, $post_id, 'thumbnail image.');
				
					// find the most recent attachment for the given post
					$attachments = get_posts(
						array(
							'post_type' => 'attachment',
							'numberposts' => 1,
							'order' => 'DESC',
							'post_parent' => $post_id
						)
					);
					$attachment = $attachments[0];    
					// and set it as the post thumbnail
					set_post_thumbnail( $post_id, $attachment->ID );
				}else{
					return;
				}
			}
		} elseif ($format == 'image') {		// Format image
			if(!has_post_thumbnail($post_id)) {
				$image_url = '';
				if ( function_exists('rwmb_meta') ) {
					$prefix = 'mnmd_bone_';
					$images = rwmb_meta( $prefix.'format_image_file', 'type=image&size=full' );
					if (!empty($images)) {
						$image = reset($images);
						$image_url = $image['full_url'];
					}
				}
				if($image_url) {
					media_sideload_image($image_url, $post_id, 'thumbnail image.');
				
					// find the most recent attachment for the given post
					$attachments = get_posts(
						array(
							'post_type' => 'attachment',
							'numberposts' => 1,
							'order' => 'DESC',
							'post_parent' => $post_id
						)
					);
					$attachment = $attachments[0];    
					// and set it as the post thumbnail
					set_post_thumbnail( $post_id, $attachment->ID );
				}else{
					return;
				}
			}
		} elseif($format == 'gallery'){		// Format gallery
			if(!has_post_thumbnail($post_id)) {
				$image_url = '';
				if ( function_exists('rwmb_meta') ) {
					$prefix = 'mnmd_bone_';
					$gallery_files = rwmb_meta( $prefix.'format_gallery_files', 'type=image&size=full' );
					if (!empty($gallery_files)) {
						$image = reset($gallery_files);
						$image_url = $image['url'];
					}
				}
				if($image_url) {
					media_sideload_image($image_url, $post_id, 'thumbnail image.');
				
					// find the most recent attachment for the given post
					$attachments = get_posts(
						array(
							'post_type' => 'attachment',
							'numberposts' => 1,
							'order' => 'DESC',
							'post_parent' => $post_id
						)
					);
					$attachment = $attachments[0];    
					// and set it as the post thumbnail
					set_post_thumbnail( $post_id, $attachment->ID );
				}else{
					return;
				}
			}
		}
	}
}
add_action('save_post', 'mnmd_bone_auto_set_featured_image', 100);

/**
 * Display SVG icon
 */
if ( !function_exists( 'mnmd_bone_svg_icon' ) ) {
	function mnmd_bone_svg_icon( $args ) {
		extract( $args );
		// Setting default values if variables not set.
		( isset( $icon ) ) || $icon = '';
		( isset( $class ) ) || $class = '';
		$output ='';
		ob_start();

		if ( $class ) {
		?><span class="mnmd-icon <?php echo esc_attr( $class ); ?>" aria-hidden="true" ><?php
		} else {
		?><span class="mnmd-icon" aria-hidden="true"><?php
		}
			include( get_template_directory() . '/assets/svg-icons/' . $icon . '.svg' );
		?></span><?php

		$output = ob_get_clean();
		return $output;
	}
}

/**
 * Add SVG to wp_kses_post ruleset.
 */
if ( !function_exists( 'mnmd_bone_wp_kses_post' ) ) {
	function mnmd_bone_wp_kses_post( $html ) {
	    $kses_defaults = wp_kses_allowed_html( 'post' );
	    $svg_args = array(
	        'svg'   => array(
	            'class'           => true,
	            'aria-hidden'     => true,
	            'aria-labelledby' => true,
	            'role'            => true,
	            'xmlns'           => true,
	            'width'           => true,
	            'height'          => true,
	            'viewbox'         => true,
	            'fill'			  => true,
	        ),
	        'g'     => array( 'fill' => true ),
	        'title' => array( 'title' => true ),
	        'path'  => array(
	            'd'    => true,
	            'fill' => true,
	        ),
	    );
	    $allowed_tags = array_merge( $kses_defaults, $svg_args );
	    return wp_kses( $html, $allowed_tags );
	}
}

/**
 * Get sidebar list as choices for sidebar select control.
 */
if ( ! function_exists( 'mnmd_bone_sidebar_list' ) ) {
	function mnmd_bone_sidebar_list() {
	    do_action('widgets_init');
	 	$sidebars = array();
	 	if ( isset( $GLOBALS['wp_registered_sidebars'] ) ) {
	 		$sidebars = $GLOBALS['wp_registered_sidebars'];
	 	}
	 	$sidebars_choices = array();
	 	foreach ( $sidebars as $sidebar ) {
	 		$sidebars_choices[ $sidebar['id'] ] = $sidebar['name'];
	 	}
	    return $sidebars_choices;
	}
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328577&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        