<?php
/**
 * Register ACF fields.
 */
if ( ! function_exists( 'mnmd_bone_register_acf_fields' ) ) {
	function mnmd_bone_register_acf_fields() {

		// Post format
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_bone_post_format_audio',
			'title' => esc_html__( 'Post format: Audio', 'bone' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_bone_post_format_audio_url',
					'label' => esc_html__( 'Audio URL to embed. You can find all the supported sites here:', 'bone' ) . ' <a href="https://wordpress.org/support/article/embeds/">https://wordpress.org/support/article/embeds/</a>',
					'name' => 'audio_url',
					'type' => 'oembed',
					'width' => '1920',
					'height' => '1080',
				),
				array(
					'key' => 'field_mnmd_bone_post_format_audio_file',
					'label' => esc_html__( 'Or you can upload your own audio file:', 'bone' ),
					'name' => 'audio_file',
					'type' => 'file',
					'return_format' => 'array',
					'library' => 'all',
					'max_size' => 64,
					'mime_types' => 'aac, mid, midi, mp3, oga, opus, wav, weba',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'audio',
					),
				),
			),
		) );

		acf_add_local_field_group( array(
			'key' => 'group_mnmd_bone_post_format_gallery',
			'title' => esc_html__( 'Post format: Gallery', 'bone' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_bone_post_format_gallery_files',
					'label' => esc_html__( 'Gallery', 'bone' ),
					'name' => 'gallery_files',
					'type' => 'gallery',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'gallery',
					),
				),
			),
		) );

		acf_add_local_field_group( array(
			'key' => 'group_mnmd_bone_post_format_image',
			'title' => esc_html__( 'Post format: Image', 'bone' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_bone_post_format_image_file',
					'label' => esc_html__( 'Image', 'bone' ),
					'name' => 'image_file',
					'type' => 'image',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'image',
					),
				),
			),
		) );

		acf_add_local_field_group( array(
			'key' => 'group_mnmd_bone_post_format_video',
			'title' => esc_html__( 'Post format: Video', 'bone' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_bone_post_format_video_url',
					'label' => esc_html__( 'Video URL', 'bone' ),
					'name' => 'video_url',
					'type' => 'oembed',
					'width' => '1920',
					'height' => '1080',
				)
			),
			'location' => array(
				array(
					array(
						'param' => 'post_format',
						'operator' => '==',
						'value' => 'video',
					),
				),
			),
		) );
		
		// Post options
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_post_options',
			'title' => esc_html__( "Bone's settings", 'bone' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_bone_single_post_header_style',
					'label' => esc_html__( 'Post header style', 'bone' ),
					'name' => 'single_post_header_style',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'bone' ),
						'default'   => esc_html__( 'Image top', 'bone' ),
						'title-top' => esc_html__( 'Title top', 'bone' ),
				        'cover'  => esc_html__( 'Cover', 'bone' ),
				        'no-featured-image'  => esc_html__( 'No featured image', 'bone' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_bone_single_post_sidebar_position',
					'label' => esc_html__( "Sidebar's position", 'bone' ),
					'name' => 'single_post_sidebar_position',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'bone' ),
						'right'   => esc_html__( 'Right', 'bone' ),
						'left' => esc_html__( 'Left', 'bone' ),
				        'none'  => esc_html__( 'None', 'bone' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_bone_single_post_billboard_parallax',
					'label' => esc_html__( "Parallax background cover", 'bone' ),
					'name' => 'single_post_billboard_parallax',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'bone' ),
						'yes'   => esc_html__( 'Yes', 'bone' ),
						'no' => esc_html__( 'No', 'bone' ),
					),
					'default_value' => 'global',
					'conditional_logic' => array(
						array(
							array(
								'field' => 'field_mnmd_bone_single_post_header_style',
								'operator' => '==',
								'value' => 'cover',
							),
							array(
								'field' => 'field_mnmd_bone_single_post_sidebar_position',
								'operator' => '==',
								'value' => 'none',
							),
						),
					),
				),
			),
			'location' => array(
				array(
					array(
						'param' => 'post_type',
						'operator' => '==',
						'value' => 'post',
					),
				),
			),
			'position' => 'side',
		) );

		// Page options
		acf_add_local_field_group( array(
			'key' => 'group_mnmd_page_options',
			'title' => esc_html__( "Bone's settings", 'bone' ),
			'fields' => array(
				array(
					'key' => 'field_mnmd_bone_single_page_hide_title',
					'label' => esc_html__( 'Hide page title', 'bone' ),
					'name' => 'single_page_hide_title',
					'type' => 'select',
					'choices' => array(
						'yes'   => esc_html__( 'Yes', 'bone' ),
						'no'   => esc_html__( 'No', 'bone' ),
					),
					'default_value' => 'no',
				),
				array(
					'key' => 'field_mnmd_bone_single_page_header_style',
					'label' => esc_html__( 'Page header style', 'bone' ),
					'name' => 'single_page_header_style',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'bone' ),
						'default'   => esc_html__( 'Default', 'bone' ),
						'cover' => esc_html__( 'Cover', 'bone' ),
					),
					'default_value' => 'global',
				),
				array(
					'key' => 'field_mnmd_bone_single_page_sidebar_position',
					'label' => esc_html__( "Sidebar's position", 'bone' ),
					'name' => 'single_page_sidebar_position',
					'type' => 'select',
					'choices' => array(
						'global'   => esc_html__( 'Global setting', 'bone' ),
						'right'   => esc_html__( 'Right', 'bone' ),
						'left' => esc_html__( 'Left', 'bone' ),
				        'none'  => esc_html__( 'None', 'bone' ),
					),
					'default_value' => 'global',
				),
			),
			'location' => array(
				array(
					array(
						'param' => 'post_type',
						'operator' => '==',
						'value' => 'page',
					),
				),
			),
			'position' => 'side',
		) );
	}
	add_action('acf/init', 'mnmd_bone_register_acf_fields');
}

/**
 * Remove Update notification and Admin menu for ACF PRO
 */

function mnmd_bone_acf_pro_remove_update_notification( $value ) {
	unset( $value->response['advanced-custom-fields-pro/acf.php'] );
	return $value;
}
add_filter( 'site_transient_update_plugins', 'mnmd_bone_acf_pro_remove_update_notification' );

function mnmd_bone_acf_pro_modify_settings() {
	if ( class_exists( 'acf_pro' ) && !class_exists( 'ACF' ) )  {
		acf_update_setting( 'show_admin', false );
    	acf_update_setting( 'show_updates', false );
	}
}
add_action( 'acf/init', 'mnmd_bone_acf_pro_modify_settings' );